@@ -4,6 +4,7 @@ from gym import spaces
 import numpy as np
 import math
 import sys
+
 sys.path.append("../../support/build")
 import libSupport
 
@@ -11,7 +12,8 @@ import libSupport
 class OriOptimizeEnv(gym.Env):
     """该环境类调用.so文件 libSupport用作计算传入的模型的支撑体积并且记录模型朝向的矩阵，
         类中的模型方向与libSupport中记录的模型方向只做同步，
-        环境选择action往哪个方向转，类中先计算旋转后的方向然后将方向同步给libSupport"""
+        环境选择action往哪个方向转，类中先计算旋转后的方向然后将方向同步给libSupport,
+        该方法是写个linux系统的，传入文件地址需要按照linux系统的文件地址"""
 
     metadata = {"render_modes": ["human", "rgb_array"], "render_fps": 4}
 
@@ -21,7 +23,8 @@ class OriOptimizeEnv(gym.Env):
         self.env = libSupport.Calculation()  # self.observation_space = 2 or 3
         self.model_object(file_path)
 
-        self.initial_ori = np.array([1, 0, 0], detype=float)  # 模型初始方向
+        ori = np.array([1, 0, 0])  # 模型初始方向 np.int64
+        self.initial_ori = ori.astype(np.float32)  # 上面的数据类型是np.int64 转换成np.float32 c++那边是32位的 python默认的float64
         self.env.getInitialOri(self.initial_ori[0], self.initial_ori[1], self.initial_ori[2])  # 传入初始方向矩阵
         self._agent_orientation = self.initial_ori
 
@@ -29,16 +32,26 @@ class OriOptimizeEnv(gym.Env):
 
         self.action_space = spaces.Discrete(2)  # rotate model around TWO axis of the XYZ is enough
 
-        self.cos = math.cos(math.pi / 36)  # 这里说明每次旋转模型，模型绕某个轴旋转 pi/36 = 5°
-        self.sin = math.sin(math.pi / 36)
+        cos = np.array([math.cos(math.pi / 36)])  # 这里说明每次旋转模型，模型绕某个轴旋转 pi/36 = 5°
+        cos = cos.astype(np.float32)
+        self.cos = cos[0]
+        sin = np.array([math.sin(math.pi / 36)])  # 先弄成numpy array 然后将其转化成np.float32 只要通过sin[0]即可调用
+        sin = sin.astype(np.float32)
+        self.sin = sin[0]
+        rotation_x = np.array([[1, 0, 0],
+                               [0, self.cos, -self.sin],
+                               [0, self.sin, self.cos]])
+        rotation_y = np.array([[self.cos, 0, self.sin],
+                               [0, 1, 0],
+                               [-self.sin, 0, self.cos]])
+        self.rotate_with_y = rotation_x.astype(np.float32)
+        self.rotate_with_x = rotation_y.astype(np.float32)
+
+        self.observation_space = spaces.Box(0, 255, dtype=np.float32)
 
         self._action_to_direction = {  # 下面的是旋转矩阵 0: 绕"x" 1: 绕"y"
-            0: np.array([[1, 0, 0],
-                         [0, self.cos, -self.sin],
-                         [0, self.sin, self.cos]]),
-            1: np.array([[self.cos, 0, self.sin],
-                         [0, 1, 0],
-                         [-self.sin, 0, self.cos]])
+            0: self.rotate_with_x,
+            1: self.rotate_with_y,
         }
 
         self._target_orientation = np.array([0, 0, 1], dtype=float)
@@ -57,19 +70,18 @@ class OriOptimizeEnv(gym.Env):
         # 这个位置传入文件地址，设定模型
         return self.env.getFilePath(file_path)
 
-    def _get_obs(self):
-        """获得观察值，即图片，应从OpenGL的程序中得到，目前还没放入接口"""
-
-        self.picture = torch.tensor((3, 227, 227))
-        # 这里会获得一个模型当前角度
-        # 这里会修改picture,传递当前的模型旋转的图片信息
-        return {"agent": self.picture}
-
     def _get_info(self):
         """info信息与观察值不同，info信息是深层次的模型信息，比如模型方向的具体数字"""
 
-        # 暂时没什么info需要返回
-        return {"orientation": self._agent_orientation}
+        return {"orientation": self._agent_orientation}  # 暂时没什么info需要返回
+
+    def _get_obs(self, img=torch.tensor((227, 227, 3))):
+        """获得观察值，即图片，应从OpenGL的程序中得到，目前还没放入接口"""
+
+        new_obs = np.moveaxis(img, 2, 0)  # 一般输入的图片的通道就是227x227x3, 调整227x227x3的通道为3x227x227
+        # 这里会获得一个模型当前角度
+        # 这里会修改picture,传递当前的模型旋转的图片信息
+        return {"observation": new_obs.astype(np.float32)}
 
     def reset(self, seed=None, return_info=True, options=None):
         """将环境的信息重置，将模型的方向也重置，不重置放进来的模型地址"""
